import uuid
from sqlalchemy.orm import Session

from app.crud.base import CRUDBase
from app.models.supplier import Supplier
from app.schemas.supplier import SupplierCreate, SupplierUpdate


class CRUDSupplier(CRUDBase[Supplier, SupplierCreate, SupplierUpdate]):
    def create(self, db: Session, *, obj_in: SupplierCreate) -> Supplier:
        db_obj = Supplier(
            id=str(uuid.uuid4()),
            name=obj_in.name,
            contact_name=obj_in.contact_name,
            email=obj_in.email,
            phone=obj_in.phone,
            address=obj_in.address,
        )
        db.add(db_obj)
        db.commit()
        db.refresh(db_obj)
        return db_obj
        
    def get_by_name(self, db: Session, *, name: str) -> Supplier:
        return db.query(Supplier).filter(Supplier.name == name).first()


supplier = CRUDSupplier(Supplier)