from sqlalchemy import Column, String, Integer, Float, DateTime, Text, ForeignKey
from sqlalchemy.sql import func
from sqlalchemy.orm import relationship
import enum

from app.db.base_class import Base


class TransactionType(str, enum.Enum):
    PURCHASE = "purchase"
    SALE = "sale"
    ADJUSTMENT = "adjustment"
    RETURN = "return"


class Transaction(Base):
    id = Column(String, primary_key=True, index=True)
    transaction_type = Column(String, nullable=False)
    quantity = Column(Integer, nullable=False)
    unit_price = Column(Float, nullable=False)
    total_price = Column(Float, nullable=False)
    reference_number = Column(String, nullable=True)
    notes = Column(Text, nullable=True)
    item_id = Column(String, ForeignKey("item.id"), nullable=False)
    user_id = Column(String, ForeignKey("user.id"), nullable=False)
    transaction_date = Column(DateTime(timezone=True), server_default=func.now())
    created_at = Column(DateTime(timezone=True), server_default=func.now())
    updated_at = Column(DateTime(timezone=True), onupdate=func.now())
    
    # Relationships
    item = relationship("Item", back_populates="transactions")
    user = relationship("User")